Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ATACADAO S.A.
CNPJ: 75.315.333/0121-15 Inscrição Estadual: 1090362886
ROD RST 287, 5500, CAMOBI, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 124948 Série: 503 Data de Emissão: 07/06/2019 17:42:41
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0675 3153 3301 2115 6550 3000 1249 4810 4857 9176
Protocolo de Autorização: 143190769065712
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
1825917 | MACA NAC.GALA | 1,052 | KG | 4,4 | 4,63
1827936 | MACA NAC.FUJI | 1,856 | KG | 3,99 | 7,41
14201952 | LEITE L.VIDA MOLICO | 3 | UN | 3,2 | 9,60
13347932 | LARANJA MIMO DO CEU | 0,876 | KG | 6,8 | 5,96
2488999 | LARANJA PERA Kg | 1,366 | KG | 1,99 | 2,72
41213970 | LEITE FERM.ACTIVIA | 1 | UN | 10,29 | 10,29
54636962 | BISC.CLUB SOCIAL | 2 | UN | 5,2 | 10,40
8353964 | LARANJA IMPORTADA | 1,566 | KG | 2,89 | 4,53
64187956 | AMENDOIM BCO FRITZ/F | 2 | UN | 3,99 | 7,98
49570912 | AGUA M.DA PEDRA | 10 | UN | 4,49 | 44,90
35476993 | DOCE PE MOLEQUE | 1 | UN | 4,99 | 4,99
14056987 | CANELA CASCA KODILAR | 1 | UN | 3,05 | 3,05
28618919 | L.PO ELEGE DES.SACHE | 1 | UN | 12,5 | 12,50
51583990 | SAC INST.BIO 60X70 | 2 | UN | 0,2 | 0,40
59113962 | RF.QUEIJO PRATO FAT. | 1 | UN | 13,98 | 13,98
59114921 | QJO MUSS.FAT.FRIMES | 1 | UN | 13,98 | 13,98
28961968 | CHA BARAO VERDE | 2 | UN | 2,4 | 4,80
28965905 | CHA BARAO CAMOMILA | 2 | UN | 1,99 | 3,98
22523724 | CREME VEG.BECEL C/S | 1 | UN | 5,99 | 5,99
62246979 | ATUM ROBINSON CRUSOE | 7 | UN | 5,19 | 36,33
29145918 | CHA MACA C/CANELA | 2 | UN | 1,99 | 3,98
22564994 | CHA OETKER CIDREIRA | 1 | UN | 2,35 | 2,35
61163968 | DOCE PACOCA | 1 | UN | 4,35 | 4,35
53810927 | IOG.BATAVO GREGO | 1 | UN | 5,79 | 5,79
5810337 | ALFACE CRESPA HID. | 1 | UN | 2,35 | 2,35
5012296 | SALSA/CHEIRO VDE IND | 1 | UN | 2,1 | 2,10
61162908 | DOCE AMENDOIM | 1 | UN | 4,75 | 4,75
35477952 | DOCE PE MOLEQUE | 1 | UN | 3,6 | 3,60
57983942 | LAVA ROUPA LIQ.OMO | 1 | UN | 7,99 | 7,99
63698951 | LAVA ROUPA LIQ.ARIEL | 1 | UN | 8,49 | 8,49
42009957 | P.HIG.PERSONAL VIP K | 1 | UN | 35,9 | 35,90
28865914 | MASSA PIZZA ROMENA | 4 | UN | 2,99 | 11,96
Valor total R$ | 302,03
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:51